pub enum CatalogCombineSelection {
All,
MoreThan(usize),
LessThan(usize),
Unique,
}Expand description
Selection rule used after definitions from all inputs have been counted.
Variants
All
Keep every message identity.
MoreThan(usize)
Keep identities with more than the provided number of definitions.
LessThan(usize)
Keep identities with less than the provided number of definitions.
Unique
Keep identities defined only once.