ObsoleteStrategy

Enum ObsoleteStrategy 

pub enum ObsoleteStrategy {
    Mark,
    Delete,
    Keep,
}
Strategy used for messages that disappear from the extracted input.

Variants



Mark

Mark missing messages obsolete and keep them in the file.



Delete

Remove missing messages entirely.



Keep

Keep missing messages as active entries.