#[non_exhaustive]pub struct CatalogAuditChecks {
pub completeness: bool,
pub extra_messages: bool,
pub icu_syntax: bool,
pub icu_compatibility: bool,
pub semantic_metadata: bool,
pub fuzzy_flags: bool,
pub obsolete_entries: bool,
}catalog only.Expand description
Enables or disables individual catalog audit checks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.completeness: boolCheck that target locales cover active source messages.
extra_messages: boolCheck for active target messages that are not active in the source catalog.
icu_syntax: boolValidate active source and target message strings as ICU MessageFormat v1.
icu_compatibility: boolCompare target ICU structure against source ICU structure.
semantic_metadata: boolValidate source-side semantic message metadata.
fuzzy_flags: boolReport active entries carrying the semantic fuzzy review marker.
obsolete_entries: boolReport obsolete entries.
Implementations
Sourceimpl CatalogAuditChecks
impl CatalogAuditChecks
Sourcepub fn with_completeness(self, completeness: bool) -> CatalogAuditChecks
pub fn with_completeness(self, completeness: bool) -> CatalogAuditChecks
Returns checks with completeness validation enabled or disabled.
Sourcepub fn with_extra_messages(self, extra_messages: bool) -> CatalogAuditChecks
pub fn with_extra_messages(self, extra_messages: bool) -> CatalogAuditChecks
Returns checks with extra-message validation enabled or disabled.
Sourcepub fn with_icu_syntax(self, icu_syntax: bool) -> CatalogAuditChecks
pub fn with_icu_syntax(self, icu_syntax: bool) -> CatalogAuditChecks
Returns checks with ICU syntax validation enabled or disabled.
Sourcepub fn with_icu_compatibility(
self,
icu_compatibility: bool,
) -> CatalogAuditChecks
pub fn with_icu_compatibility( self, icu_compatibility: bool, ) -> CatalogAuditChecks
Returns checks with ICU compatibility validation enabled or disabled.
Sourcepub fn with_semantic_metadata(
self,
semantic_metadata: bool,
) -> CatalogAuditChecks
pub fn with_semantic_metadata( self, semantic_metadata: bool, ) -> CatalogAuditChecks
Returns checks with semantic metadata validation enabled or disabled.
Sourcepub fn with_fuzzy_flags(self, fuzzy_flags: bool) -> CatalogAuditChecks
pub fn with_fuzzy_flags(self, fuzzy_flags: bool) -> CatalogAuditChecks
Returns checks with fuzzy-entry reporting enabled or disabled.
Sourcepub fn with_obsolete_entries(self, obsolete_entries: bool) -> CatalogAuditChecks
pub fn with_obsolete_entries(self, obsolete_entries: bool) -> CatalogAuditChecks
Returns checks with obsolete-entry reporting enabled or disabled.