#[non_exhaustive]pub struct CatalogAuditIcuOptions {
pub syntax_policy: IcuSyntaxPolicy,
}Available on crate feature
catalog only.Expand description
ICU-specific options used by catalog audit checks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.syntax_policy: IcuSyntaxPolicyICU parser behavior used by syntax and compatibility checks.
Implementations
Sourceimpl CatalogAuditIcuOptions
impl CatalogAuditIcuOptions
Sourcepub fn new() -> CatalogAuditIcuOptions
pub fn new() -> CatalogAuditIcuOptions
Creates audit ICU options with default strict parser behavior.
Sourcepub fn with_syntax_policy(
self,
syntax_policy: IcuSyntaxPolicy,
) -> CatalogAuditIcuOptions
pub fn with_syntax_policy( self, syntax_policy: IcuSyntaxPolicy, ) -> CatalogAuditIcuOptions
Returns options that parse messages with the given ICU syntax policy.