pub struct CatalogLocaleCoverage {
pub locale: String,
pub total: usize,
pub translated: usize,
pub missing: usize,
pub empty: usize,
pub obsolete: usize,
pub extra: usize,
pub details: Vec<CatalogCoverageMessage>,
}catalog only.Expand description
Coverage counters for one target locale.
Fields
locale: StringTarget locale represented by these counters.
total: usizeActive source messages expected for this locale.
translated: usizeExpected messages with non-empty, non-fuzzy active translations.
missing: usizeExpected messages with no target entry.
empty: usizeExpected messages with an empty effective translation.
obsolete: usizeExpected messages with only an obsolete target entry.
extra: usizeActive target messages that are not present in the active source set.
details: Vec<CatalogCoverageMessage>Optional per-message detail rows.
Implementations
Sourceimpl CatalogLocaleCoverage
impl CatalogLocaleCoverage
Sourcepub const fn fuzzy(&self) -> usize
pub const fn fuzzy(&self) -> usize
Returns expected messages with a non-empty active translation carrying
the semantic fuzzy review marker.
Fuzzy is the remaining mutually exclusive expected-message state after subtracting translated, missing, empty, and obsolete messages.
Sourcepub const fn incomplete(&self) -> usize
pub const fn incomplete(&self) -> usize
Returns messages that still need translator attention.
Sourcepub fn completion_ratio(&self) -> f64
pub fn completion_ratio(&self) -> f64
Returns completion as a 0.0..=1.0 ratio.
Sourcepub fn completion_percent(&self) -> f64
pub fn completion_percent(&self) -> f64
Returns completion as a 0.0..=100.0 percentage.