Diagnostic

Struct Diagnostic 

pub struct Diagnostic {
    pub severity: DiagnosticSeverity,
    pub code: String,
    pub message: String,
    pub msgid: Option<String>,
    pub msgctxt: Option<String>,
}
Non-fatal issue collected while parsing or updating catalogs.

Fields

severity: DiagnosticSeverity

Severity level for the diagnostic.

code: String

Stable machine-readable code for the diagnostic.

message: String

Human-readable explanation of the condition.

msgid: Option<String>

Source msgid, when the diagnostic can be tied to one message.

msgctxt: Option<String>

Source msgctxt, when the diagnostic can be tied to one message.