#[non_exhaustive]pub struct IcuParserOptions {
pub ignore_tag: bool,
pub requires_other_clause: bool,
}Expand description
Options controlling ICU parsing behavior.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ignore_tag: boolWhen true, rich-text style tags are treated as plain text.
requires_other_clause: boolWhen true, select and plural arguments must include an other clause.
Implementations
Sourceimpl IcuParserOptions
impl IcuParserOptions
Sourcepub fn with_ignore_tag(self, ignore_tag: bool) -> IcuParserOptions
pub fn with_ignore_tag(self, ignore_tag: bool) -> IcuParserOptions
Returns options that enable or disable rich-text tag parsing.
Sourcepub fn with_requires_other_clause(
self,
requires_other_clause: bool,
) -> IcuParserOptions
pub fn with_requires_other_clause( self, requires_other_clause: bool, ) -> IcuParserOptions
Returns options that enable or disable required other clauses.