ParseCatalogOptions

Struct ParseCatalogOptions 

#[non_exhaustive]
pub struct ParseCatalogOptions<'a> { pub content: &'a str, pub locale: Option<&'a str>, pub source_locale: &'a str, pub mode: CatalogMode, pub strict: bool, }
Available on crate feature catalog only.
Options for parsing a catalog into the higher-level message model.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
content: &'a str

Catalog content to parse.

locale: Option<&'a str>

Optional explicit locale override.

source_locale: &'a str

Source locale used for source-side semantics and validation.

mode: CatalogMode

High-level catalog mode used when interpreting catalog content.

strict: bool

Whether unsupported ICU plural projection cases should become hard errors.

Implementations

Source

impl<'a> ParseCatalogOptions<'a>

pub fn new(content: &'a str, source_locale: &'a str) -> ParseCatalogOptions<'a>

Creates parse options with required fields set.

Optional fields default to an inferred locale, ICU-native PO mode, and non-strict plural projection.

Examples found in repository?
crates/ferrocat/examples/runtime_compile.rs (line 11)
6fn catalog(
7    content: &str,
8    locale: &str,
9) -> Result<NormalizedParsedCatalog, Box<dyn std::error::Error>> {
10    Ok(
11        parse_catalog(ParseCatalogOptions::new(content, "en").with_locale(locale))?
12            .into_normalized_view()?,
13    )
14}
More examples
Hide additional examples
crates/ferrocat/examples/release_audit.rs (line 8)
3fn catalog(
4    content: &str,
5    locale: &str,
6) -> Result<NormalizedParsedCatalog, Box<dyn std::error::Error>> {
7    Ok(
8        ferrocat::parse_catalog(ParseCatalogOptions::new(content, "en").with_locale(locale))?
9            .into_normalized_view()?,
10    )
11}
pub fn with_locale(self, locale: &'a str) -> ParseCatalogOptions<'a>

Returns options that use the given explicit catalog locale.

Examples found in repository?
crates/ferrocat/examples/runtime_compile.rs (line 11)
6fn catalog(
7    content: &str,
8    locale: &str,
9) -> Result<NormalizedParsedCatalog, Box<dyn std::error::Error>> {
10    Ok(
11        parse_catalog(ParseCatalogOptions::new(content, "en").with_locale(locale))?
12            .into_normalized_view()?,
13    )
14}
More examples
Hide additional examples
crates/ferrocat/examples/release_audit.rs (line 8)
3fn catalog(
4    content: &str,
5    locale: &str,
6) -> Result<NormalizedParsedCatalog, Box<dyn std::error::Error>> {
7    Ok(
8        ferrocat::parse_catalog(ParseCatalogOptions::new(content, "en").with_locale(locale))?
9            .into_normalized_view()?,
10    )
11}
pub fn with_mode(self, mode: CatalogMode) -> ParseCatalogOptions<'a>

Returns options that interpret catalog content with the given mode.

pub fn with_strict(self, strict: bool) -> ParseCatalogOptions<'a>

Returns options that enable or disable strict plural projection.