pub struct CatalogAuditChecks {
pub completeness: bool,
pub extra_messages: bool,
pub icu_syntax: bool,
pub icu_compatibility: bool,
pub semantic_metadata: bool,
pub fuzzy_flags: bool,
pub obsolete_entries: bool,
}Expand description
Enables or disables individual catalog audit checks.
Fields
completeness: boolCheck that target locales cover active source messages.
extra_messages: boolCheck for active target messages that are not active in the source catalog.
icu_syntax: boolValidate active source and target message strings as ICU MessageFormat v1.
icu_compatibility: boolCompare target ICU structure against source ICU structure.
semantic_metadata: boolValidate source-side semantic message metadata.
fuzzy_flags: boolReport existing fuzzy flags.
obsolete_entries: boolReport obsolete entries.