#[non_exhaustive]pub struct UpdateCatalogFileOptions<'a> {
pub target_path: &'a Path,
pub options: UpdateCatalogOptions<'a>,
}Available on crate feature
catalog only.Expand description
Options for updating a catalog file on disk.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_path: &'a PathPath to the catalog file that should be read and conditionally written.
options: UpdateCatalogOptions<'a>In-memory update options applied to the file content.
Implementations
Sourceimpl<'a> UpdateCatalogFileOptions<'a>
impl<'a> UpdateCatalogFileOptions<'a>
Sourcepub fn new(
target_path: &'a Path,
source_locale: &'a str,
input: impl Into<CatalogUpdateInput>,
) -> UpdateCatalogFileOptions<'a>
pub fn new( target_path: &'a Path, source_locale: &'a str, input: impl Into<CatalogUpdateInput>, ) -> UpdateCatalogFileOptions<'a>
Creates file update options with required fields set.
Optional fields on the nested update options use
UpdateCatalogOptions::new defaults.
Sourcepub fn with_options(
self,
options: UpdateCatalogOptions<'a>,
) -> UpdateCatalogFileOptions<'a>
pub fn with_options( self, options: UpdateCatalogOptions<'a>, ) -> UpdateCatalogFileOptions<'a>
Returns file update options that use the given in-memory update options.